Struct orzir_core::graph::Graph

source ·
pub struct Graph<K, N, E>
where K: Copy + Eq + Hash, N: GraphNode<K, E>, E: GraphEdge<K>,
{ /* private fields */ }
A graph data structure.

Implementations

source

impl<K, N, E> Graph<K, N, E>
where K: Copy + Eq + Hash, N: GraphNode<K, E>, E: GraphEdge<K>,

source

pub fn add_node(&mut self, node: N)

Add a node to the graph.

source

pub fn add_node_by_key(&mut self, key: K)

source

pub fn node(&self, key: K) -> Option<&N>

Get a node from the graph.

source

pub fn node_mut(&mut self, key: K) -> Option<&mut N>

Get a mutable node from the graph.

source

pub fn add_edge(&mut self, edge: E)

Add an edge to the graph.

source

pub fn dfs<F>(&self, key: K, f: F)
where F: FnMut(&N),

Iterate over the nodes of the graph with DFS.

source

pub fn bfs<F>(&self, key: K, f: F)
where F: FnMut(&N),

Iterate over the nodes of the graph with BFS.

source

impl<K, N, E> Graph<K, N, E>
where K: Copy + Eq + Hash, N: GraphNode<K, E>, E: WeightedEdge<K>,

source

pub fn dijkstra(&self, from: K) -> HashMap<K, (Vec<K>, E::Weight)>

Dijkstra’s algorithm.

This will produce the shortest path from the start node to the end node, with a vector of nodes in between and the total weight of the path.